@@ -116,12 +116,12 @@ regression_type1 <- function(datatable,
   )
 
   if (is.null(locus_id)) {
-    plot_title <- bquote(italic(.(locusname))) # nolint
+    plot_title <- "bquote(italic(.(locusname)))"
   } else {
-    plot_title <- bquote("Locus: " ~
-                           italic(.(locus_id)) ~ # nolint
-                           " - Sample: " ~
-                           .(locusname))
+    plot_title <- paste0(
+      "bquote('Locus: ' ~ italic(.(locus_id)) ~",
+      "' - Sample: ' ~ .(locusname))"
+    )
   }
 
   # result_list
@@ -220,6 +220,12 @@ regression_type1 <- function(datatable,
           }
         }
 
+        x_max <- ifelse(
+          max(gdat$true_methylation) <= 1,
+          1,
+          100
+        )
+
         p <- ggplot2::ggplot(data = gdat,
                              ggplot2::aes_string(
                                x = "true_methylation",
@@ -229,18 +235,19 @@ regression_type1 <- function(datatable,
           ggplot2::ylab(custom_ylab) +
           ggplot2::xlab("actual methylation (%)") +
           ggplot2::labs(
-            title = plot_title,
+            title = eval(parse(text = plot_title)),
             subtitle = paste("CpG:", vec_cal[i])
           ) +
           ggplot2::geom_text(
             data = data.frame(),
             ggplot2::aes(x = -Inf,
-                         y = c(max(gdat$true_methylation),
-                               0.95 * max(gdat$true_methylation)),
+                         y = c(x_max, 0.95 * x_max),
                          hjust = 0, vjust = 1),
             label = lb1,
             parse = FALSE
-          )
+          ) +
+          ggplot2::xlim(0, x_max) +
+          ggplot2::ylim(0, x_max)
 
         if (is.null(mode)) {
           if ("ymin" %in% colnames(gdat) &&
@@ -249,7 +256,8 @@ regression_type1 <- function(datatable,
               ggplot2::aes_string(
                 ymin = "ymin",
                 ymax = "ymax"
-              )
+              ),
+              flatten = 0.5
             )
           }
         }
